@@ -2,7 +2,7 @@ package WebService::Stripe;
 use Moo;
 with 'WebService::Client';
 
-our $VERSION = '0.0800'; # VERSION
+our $VERSION = '0.0900'; # VERSION
 
 use Carp qw(croak);
 use Method::Signatures;
@@ -60,14 +60,20 @@ method create_card(HashRef $data, :$customer_id!, :$headers) {
         "/v1/customers/$customer_id/cards", $data, headers => $headers );
 }
 
-method get_charge(Str $id, :$headers) {
-    return $self->get( "/v1/charges/$id", {}, headers => $headers );
+method get_charge(HashRef|Str $charge, :$query, :$headers) {
+    $charge = $charge->{id} if ref $charge;
+    return $self->get( "/v1/charges/$charge", $query, headers => $headers );
 }
 
 method create_charge(HashRef $data, :$headers) {
     return $self->post( "/v1/charges", $data, headers => $headers );
 }
 
+method update_charge(HashRef|Str $charge, HashRef $data, :$headers) {
+    $charge = $charge->{id} if ref $charge;
+    return $self->post( "/v1/charges/$charge", $data, headers => $headers );
+}
+
 method capture_charge(Str $id, HashRef :$data, :$headers) {
     return $self->post( "/v1/charges/$id/capture", $data, headers => $headers );
 }
@@ -76,6 +82,11 @@ method refund_charge(Str $id, HashRef :$data, :$headers) {
     return $self->post( "/v1/charges/$id/refunds", $data, headers => $headers );
 }
 
+method add_source(HashRef|Str $cust, HashRef $data, :$headers) {
+    $cust = $cust->{id} if ref $cust;
+    return $self->post( "/v1/customers/$cust/sources", $data, headers => $headers );
+}
+
 method create_token(HashRef $data, :$headers) {
     return $self->post( "/v1/tokens", $data, headers => $headers );
 }
@@ -165,7 +176,7 @@ WebService::Stripe - Stripe API bindings
 
 =head1 VERSION
 
-version 0.0800
+version 0.0900
 
 =head1 SYNOPSIS
 
@@ -175,6 +186,11 @@ version 0.0800
     );
     my $customer = $stripe->get_customer('cus_57eDUiS93cycyH');
 
+=head1 TESTING
+
+Set the PERL_STRIPE_TEST_API_KEY environment variable to your Stripe test
+secret, then run tests as you normally would using prove.
+
 =head1 HEADERS
 
 WebService::Stripe supports passing custom headers to any API request by passing a hash of header values as the optional C<headers> named parameter:
@@ -261,9 +277,11 @@ Example:
 
 =head2 get_charge
 
-    get_charge($id)
+    get_charge($id, query => { expand => ['customer'] })
 
-Returns the charge for the given id.
+Returns the charge for the given id. The optional :$query parameter allows
+passing query arguments. Passing an arrayref as a query param value will expand
+it into Stripe's expected array format.
 
 =head2 create_charge
 
@@ -285,6 +303,18 @@ The data param is optional.
 Refunds the charge with the given id.
 The data param is optional.
 
+=head2 update_charge
+
+    update_charge($id, $data)
+
+Updates an existing charge object.
+
+=head2 add_source
+
+    add_source($cust_id, $card_data)
+
+Adds a new funding source (credit card) to an existing customer.
+
 =head2 get_token
 
     get_token($id)
